@@ -8,7 +8,6 @@
 #include <dirent.h>
 #include <sys/statvfs.h>
 #include <sys/types.h>
-#include <attr/xattr.h>
 #include <time.h>
 #include <pthread.h>
 #include <libsmbclient.h>
@@ -24,6 +23,7 @@ static int		function_free_space_size	= 0;
 static int		function_quiet_flag		= 1;
 static int		function_show_dollar_shares	= 0;
 static int		function_show_hidden_hosts	= 0;
+static int		function_noexec_attr		= 0;
 
 
 int function_set_free_space_size(int blocks_count){
@@ -66,6 +66,16 @@ static inline int function_get_hidden_hosts_visibility(void){
     return g_atomic_int_get(&function_show_hidden_hosts);
 }
 
+int function_set_noexec_attr(int flag){
+    DPRINTF(7, "flag=%d\n", flag);
+    g_atomic_int_set(&function_noexec_attr, flag);
+    return 1;
+}
+
+static inline int function_get_noexec_attr(void){
+    return g_atomic_int_get(&function_noexec_attr);
+}
+
 static inline int function_check_xattr_name(const char *name){
     static char	*xattr_name = "system.nt_sec_desc.";
     return (strncmp(name, xattr_name, strlen(xattr_name)) == 0);
@@ -90,19 +100,6 @@ static int function_open(const char *path, struct fuse_file_info *fi){
     return 0;
 }
 
-static int function_creat(const char *path, mode_t mode,
-			struct fuse_file_info *fi){
-    samba_fd	fd;
-
-    DPRINTF(5, "(%s, mode=%0x, flags=%o, fh=%llx)\n", path, mode,
-	fi->flags, (long long) fi->fh);
-    if (smbitem_what_is(path) != SMBITEM_SMB_SHARE_ITEM) return -EINVAL;
-
-    if ((fd = samba_creat(path, fi->flags)) == NULL) return -errno;
-    function_store_fd(fi, fd);
-    return 0;
-}
-
 static int function_read(const char *path, char *buf, size_t size, off_t offset,
 			struct fuse_file_info *fi){
     int		result;
@@ -401,6 +398,8 @@ static int function_stat(const char *path, struct stat *stbuf){
 
 	case SMBITEM_SMB_SHARE_ITEM:
 	    if (samba_stat(path, stbuf) != 0) return -errno;
+	    if (S_ISREG(stbuf->st_mode) && function_get_noexec_attr())
+		stbuf->st_mode &= ~(S_IXUSR | S_IXGRP | S_IXOTH);
 	    return 0;
 
 	default:
@@ -447,6 +446,8 @@ static int function_fstat(const char *path, struct stat *stbuf,
     }
 
     if (samba_fstat(fd, stbuf) != 0) return -errno;
+    if (S_ISREG(stbuf->st_mode) && function_get_noexec_attr())
+	stbuf->st_mode &= ~(S_IXUSR | S_IXGRP | S_IXOTH);
     return 0;
 }
 
@@ -589,7 +590,6 @@ static int function_statfs(const char *path, struct statvfs *stbuf){
 
 struct fuse_operations smb_oper = {
     .open	= function_open,
-    .create	= function_creat,
     .read	= function_read,
     .write	= function_write,
     .release	= function_close,
