@@ -64,7 +64,7 @@ const char *smbnetfs_option_list =
 	"    -o stat_workaround_depth=N   konquerror and gnome terminal hack (3)\n"
 	"    -o time_step=T               Scheduler sleep interval (10s)\n"
 	"    -o config_update_period=T    Configuration update interval (300s)\n"
-	"    -o max_ctx_count=N           Maximum number of childs (15)\n"
+	"    -o max_ctx_count=N           Maximum number of children processes (15)\n"
 	"    -o max_retry_count=N         Number of retries before fail (2)\n"
 	"    -o listen_timeout=T          Child process inactivity timeout (300s)\n"
 	"    -o reply_timeout=T           Child process reply timeout (30s)\n"
@@ -294,7 +294,7 @@ static int reconfigure_analyse_simple_option(const char *option, char *value, in
 
 #ifdef HAVE_LIBSECRET
     /* auth-libsecret.h */
-    if (strcasecmp(option, "use_libsecter") == 0)
+    if (strcasecmp(option, "use_libsecret") == 0)
 	return reconfigure_set_boolean(value, libsecret_enable);
     if (strcasecmp(option, "libsecret_timeout") == 0)
 	return reconfigure_set_number(value, libsecret_set_request_timeout);
@@ -355,6 +355,9 @@ static int reconfigure_analyse_simple_option(const char *option, char *value, in
 	return reconfigure_set_boolean(value, function_set_dollar_share_visibility);
     if (strcasecmp(option, "show_hidden_hosts") == 0)
 	return reconfigure_set_boolean(value, function_set_hidden_hosts_visibility);
+    if (strcasecmp(option, "noexec_attr") == 0)
+	return reconfigure_set_boolean(value, function_set_noexec_attr);
+
 
     /* neg_cache.h */
     if (strcasecmp(option, "neg_cache") == 0)
